/*
    Theseus - maximum likelihood superpositioning of macromolecular structures

    Copyright (C) 2004-2009 Douglas L. Theobald

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the:

    Free Software Foundation, Inc.,
    59 Temple Place, Suite 330,
    Boston, MA  02111-1307  USA

    -/_|:|_|_\-
*/

#ifndef QUARTICHORN_SEEN
#define QUARTICHORN_SEEN

#include "FragCoords.h"
#include "Coords.h"

void
ComputeQuartHornFrag(const FragCoords *coords1, const FragCoords *coords2, double *coeff);

double
QuarticHornFrag(const FragCoords *coords1, const FragCoords *coords2, double *coeff);

void
FragDistPu(CoordsArray *cdsA, int fraglen, int center_ca, int pu);

#endif
